@@ -48,7 +48,13 @@ class DBAPIClient(Client):
         Some database drivers do not support multiple commands in a single
         execute statement. Use this optiion to split commands by a given
         character (e.g. ';') and send them one at a time. Defaults to
-        None (no spltting)
+        None (no splitting)
+
+    Examples
+    --------
+    >>> from ploomber.clients import DBAPIClient
+    >>> import sqlite3
+    >>> client = DBAPIClient(sqlite3.connect, dict(database='my.db'))
     """
     def __init__(self, connect_fn, connect_kwargs, split_source=None):
         super().__init__()
@@ -69,6 +75,9 @@ class DBAPIClient(Client):
 
         return self._connection
 
+    def cursor(self):
+        return self.connection.cursor()
+
     def execute(self, code):
         """Execute code with the existing connection
         """
@@ -112,6 +121,9 @@ class SQLAlchemyClient(Client):
         it will never split, a string value is interpreted as the token
         to use for splitting statements regardless of the database type
 
+    create_engine_kwargs : dict, optional
+        Keyword arguments to pass to ``sqlalchemy.create_engine``
+
     Notes
     -----
     SQLite client does not support sending more than one command at a time,
@@ -121,11 +133,12 @@ class SQLAlchemyClient(Client):
     split_source_mapping = {'sqlite': ';'}
 
     @requires(['sqlalchemy'], 'SQLAlchemyClient')
-    def __init__(self, uri, split_source='default'):
+    def __init__(self, uri, split_source='default', create_engine_kwargs=None):
         super().__init__()
         self._uri = uri
         self._uri_parsed = urlparse(uri)
         self._uri_safe = safe_uri(self._uri_parsed)
+        self._create_engine_kwargs = create_engine_kwargs or dict()
         self.flavor = self._uri_parsed.scheme
         self._engine = None
         self.split_source = split_source
@@ -150,6 +163,9 @@ class SQLAlchemyClient(Client):
 
         return self._connection
 
+    def cursor(self):
+        return self.connection.cursor()
+
     def execute(self, code):
         cur = self.connection.cursor()
 
@@ -186,7 +202,8 @@ class SQLAlchemyClient(Client):
         """Returns a SQLAlchemy engine
         """
         if self._engine is None:
-            self._engine = create_engine(self._uri)
+            self._engine = create_engine(self._uri,
+                                         **self._create_engine_kwargs)
 
         return self._engine
 
