@@ -50,6 +50,8 @@ products from one task aren't available for the next one, the user has to
 configure a File.client. When executing each task (Task.build), we use the
 client to fetch upstream dependencies and execute a given task.
 """
+from functools import reduce
+import fnmatch
 import os
 from collections.abc import Iterable
 import traceback
@@ -88,7 +90,8 @@ from ploomber.dag.DAGConfiguration import DAGConfiguration
 from ploomber.dag.DAGLogger import DAGLogger
 from ploomber.dag.dagclients import DAGClients
 from ploomber.dag.abstractdag import AbstractDAG
-from ploomber.dag.util import check_duplicated_products
+from ploomber.dag.util import (check_duplicated_products,
+                               fetch_remote_metadata_in_parallel)
 from ploomber.tasks.abc import Task
 
 
@@ -164,9 +167,6 @@ class DAG(AbstractDAG):
                 'an instance of executors.Executor, got type {}'.format(
                     type(executor)))
 
-        # FIXME: delete, no longer used
-        self._did_render = False
-
         self.on_finish = None
         self.on_failure = None
         self._available_callback_kwargs = {'dag': self}
@@ -284,7 +284,7 @@ class DAG(AbstractDAG):
         self._G.remove_node(name)
         return t
 
-    def render(self, force=False, show_progress=True):
+    def render(self, force=False, show_progress=True, remote=False):
         """
         Render resolves all placeholders in tasks and determines whether
         a task should run or not based on the task.product metadata, this
@@ -292,13 +292,20 @@ class DAG(AbstractDAG):
 
         Parameters
         ----------
-        force
+        force : bool, default=False
             Ignore product metadata status and prepare all tasks to be
             executed. This option renders much faster in DAGs with products
             whose metadata is stored in remote systems, because there is no
             need to fetch metadata over the network. If the DAG won't be
             built, this option is recommended.
 
+        show_progress : bool, default=True
+            Show progress bar
+
+        remote : bool, default=False
+            Use remote metadata for determining task status. In most scenarios,
+            you want this to be False, Ploomber uses this internally when
+            exporting pipelines to other platforms (via Soopervisor).
         """
         g = self._to_graph()
 
@@ -317,21 +324,24 @@ class DAG(AbstractDAG):
         # and over
         for dag in dags:
             if dag is not self:
-                dag._render_current(force=force, show_progress=show_progress)
+                dag._render_current(force=force,
+                                    show_progress=show_progress,
+                                    remote=remote)
 
         # then, render this dag
-        self._render_current(force=force, show_progress=show_progress)
+        self._render_current(force=force,
+                             show_progress=show_progress,
+                             remote=remote)
 
         return self
 
-    def _render_current(self, force, show_progress):
+    def _render_current(self, force, show_progress, remote):
         """
         Render tasks, and update exec_status
         """
-        # FIXME: should also render again if errored render, maybe change
-        # _did_render for needs render which is on the first time
-        # and when there's an error
-        if not self._params.cache_rendered_status or not self._did_render:
+        if not self._params.cache_rendered_status:
+            fetch_remote_metadata_in_parallel(self)
+
             self._logger.info('Rendering DAG %s', self)
 
             if show_progress:
@@ -360,7 +370,8 @@ class DAG(AbstractDAG):
                     try:
                         t.render(
                             force=force,
-                            outdated_by_code=self._params.outdated_by_code)
+                            outdated_by_code=self._params.outdated_by_code,
+                            remote=remote)
                     except Exception:
                         tr = traceback.format_exc()
                         exceptions.append(task=t, message=tr)
@@ -382,7 +393,7 @@ class DAG(AbstractDAG):
 
             check_duplicated_products(self)
 
-        self._exec_status = DAGStatus.WaitingExecution
+            self._exec_status = DAGStatus.WaitingExecution
 
     def build(self,
               force=False,
@@ -601,13 +612,15 @@ class DAG(AbstractDAG):
                         target,
                         force=False,
                         show_progress=True,
-                        debug=False):
+                        debug=False,
+                        skip_upstream=False):
         """Partially build a dag until certain task
 
         Parameters
         ----------
-        target : str,
-            Name of the target task (last one to build)
+        target : str
+            Name of the target task (last one to build). Can pass a wildcard
+            such as 'tasks-*'
 
         force : bool, default=False
             If True, it will run all tasks regardless of status, defaults to
@@ -621,22 +634,52 @@ class DAG(AbstractDAG):
             this modifies the executor and temporarily sets it to Serial
             with subprocess off and catching exceptions/warnings off. Restores
             the original executor at the end.
+
+        skip_upstream : bool, default=False
+            If False, includes all upstream dependencies required to build
+            target, otherwise it skips them. Note that if this is True and
+            it's not possible to build a given task (e.g., missing upstream
+            products), this will fail
         """
-        lineage = self[target]._lineage
         dag_copy = deepcopy(self)
 
-        to_pop = set(dag_copy) - {target}
+        # task names are usually str, although this isn't strictly enforced
+        if isinstance(target, str) and '*' in target:
+            targets = set(fnmatch.filter(self._iter(), target))
 
-        if lineage:
-            to_pop = to_pop - lineage
+            to_include = [
+                self[target]._lineage for target in targets
+                if self[target]._lineage
+            ]
 
-        for task in to_pop:
+            if to_include:
+                lineage = reduce(lambda a, b: a.union(b), to_include)
+            else:
+                lineage = set()
+
+        else:
+            targets = {target}
+            lineage = self[target]._lineage or set()
+
+        to_remove = set(dag_copy) - targets - lineage
+
+        for task in to_remove:
             dag_copy.pop(task)
 
         # clear metadata in the original dag, because building the copy
         # will make it outdated, we have to force reload from disk
         self._clear_metadata()
 
+        if skip_upstream:
+            dag_copy.render(force=force, show_progress=show_progress)
+            # to prevent call to dag_copy.render() inside dag_copy.build()
+            # to overwrite Skipped status
+            dag_copy._params.cache_rendered_status = True
+
+            for name, task in dag_copy.items():
+                if name not in targets:
+                    dag_copy[name].exec_status = TaskStatus.Skipped
+
         return dag_copy.build(force=force,
                               show_progress=show_progress,
                               debug=debug)
@@ -803,9 +846,6 @@ class DAG(AbstractDAG):
             Pass a string to group this edge, upon rendering, upstream
             products are available via task[group_name][tas_name]
         """
-        # if a new task is added, rendering is required again
-        self._did_render = False
-
         attrs = {} if group_name is None else {'group_name': group_name}
 
         # when adding a task group (but not a dag)
