@@ -65,6 +65,13 @@ class DAGSpecInitializationError(Exception):
     pass
 
 
+class DAGSpecNotFound(Exception):
+    """
+    Raised when trying to find dagspec automatically but the file doesn't exist
+    """
+    pass
+
+
 class SpecValidationError(Exception):
     """
     Raised when failing to validate a spec
@@ -85,6 +92,13 @@ class SpecValidationError(Exception):
         return msg
 
 
+class RemoteFileNotFound(Exception):
+    """
+    Raised by File clients when atempting to download a file that doesn't exist
+    """
+    pass
+
+
 def display_errors(errors):
     return '\n'.join(f'{_display_error_loc(e)} ({e["msg"]})' for e in errors)
 
