@@ -1,6 +1,6 @@
 from ploomber.products.Product import Product
 from ploomber.products.MetaProduct import MetaProduct
-from ploomber.products.File import File
+from ploomber.products.file import File
 from ploomber.products.GenericProduct import (GenericProduct,
                                               GenericSQLRelation, SQLRelation)
 from ploomber.products.sql import SQLiteRelation, PostgresRelation
