@@ -92,19 +92,21 @@ from collections.abc import MutableMapping
 from glob import iglob
 from itertools import chain
 import pprint
+import warnings
 
 from ploomber.dag.DAG import DAG
 from ploomber.placeholders.SourceLoader import SourceLoader
 from ploomber.util.util import call_with_dictionary, add_to_sys_path
 from ploomber.util import dotted_path
-from ploomber.util.default import entry_point
-from ploomber.spec.TaskSpec import TaskSpec, suffix2taskclass
+from ploomber.util.default import entry_point, entry_point_relative
+from ploomber.spec.taskspec import TaskSpec, suffix2taskclass
 from ploomber.util import validate
 from ploomber.util import default
 from ploomber.dag.DAGConfiguration import DAGConfiguration
 from ploomber.exceptions import DAGSpecInitializationError
 from ploomber.env.EnvDict import EnvDict
-from ploomber.env.expand import expand_raw_dictionary, expand_raw_dictionaries
+from ploomber.env.expand import (expand_raw_dictionary_and_extract_tags,
+                                 expand_raw_dictionaries_and_extract_tags)
 from ploomber.tasks import NotebookRunner
 from ploomber.tasks.taskgroup import TaskGroup
 from ploomber.validators.string import (validate_product_class_name,
@@ -131,17 +133,18 @@ class DAGSpec(MutableMapping):
     Parameters
     ----------
     data : str, pathlib.Path or dict
-        Path to a YAML spec or dict spec to construct the DAG
+        Path to a YAML spec or dict spec
 
     env : dict, pathlib.path or str, optional
-        Dictionary or path/str to a YAML file with the environment to use,
-        tags in any of the keys (i.e. {{some_tag}}) in "data" will be replaced
-        by the corresponding values in "env". A regular :py:mod:`ploomber.Env`
-        object is created, see documentation for details. If None and
-        data is a dict, no env is loaded. If None and loaded from a YAML spec,
-        an env.yaml file is loaded (in the current working diirectory), if
-        it doesn't exist, it is loaded from the YAML spec parent folder, if it
-        exists. If none of these exist, no env is loaded.
+        If path it must be a YAML file. Environment to load. Any string with
+        the format '{{placeholder}}' in the spec is replaced by the
+        corresponding value in the given key (i.e., placeholder). If ``env``
+        is None and spec is a dict, no env is loaded. If None and loaded
+        from a YAML file, an ``env.yaml`` file is loaded from the current
+        working diirectory, if it doesn't exist, it is loaded from the YAML
+        spec parent folder. If none of these exist, no env is loaded.
+        A :py:mod:`ploomber.Env` object is initialized, see documentation for
+        details.
 
     lazy_import : bool, optional
         Whether to import dotted paths to initialize PythonCallables with the
@@ -156,6 +159,12 @@ class DAGSpec(MutableMapping):
     reload : bool, optional
         Reloads modules before getting dotted paths. Has no effect if
         lazy_import=True
+
+    Attributes
+    ----------
+    path : str or None
+        Returns the path used to load the data. None if loaded from a
+        dictionary
     """
 
     # NOTE: lazy_import is used where we need to initialized a a spec but don't
@@ -180,9 +189,7 @@ class DAGSpec(MutableMapping):
                 raise ValueError('parent_path must be None when '
                                  f'initializing {type(self).__name__} with '
                                  'a path to a YAML spec')
-            # this is only used to display an error message with the path
-            # to the loaded file
-            path_for_errors = data
+            self._path = data
             # resolve the parent path to make sources and products unambiguous
             # even if the current working directory changes
             path_to_entry_point = Path(data).resolve()
@@ -213,7 +220,7 @@ class DAGSpec(MutableMapping):
 
         # initialized with a dictionary...
         else:
-            path_for_errors = None
+            self._path = None
             # FIXME: add test cases, some of those features wont work if
             # _parent_path is None. We should make sure that we either raise
             # an error if _parent_path is needed or use the current working
@@ -232,7 +239,7 @@ class DAGSpec(MutableMapping):
             self.data = {'tasks': self.data}
 
         # validate keys defined at the top (nested keys are not validated here)
-        self._validate_top_keys(self.data, path_for_errors)
+        self._validate_top_keys(self.data, self._path)
 
         logger.debug('DAGSpec enviroment:\n%s', pp.pformat(env))
 
@@ -252,7 +259,8 @@ class DAGSpec(MutableMapping):
         else:
             self.env = EnvDict(env, path_to_here=self._parent_path)
 
-        self.data = expand_raw_dictionary(self.data, self.env)
+        self.data, tags = expand_raw_dictionary_and_extract_tags(
+            self.data, self.env)
 
         logger.debug('Expanded DAGSpec:\n%s', pp.pformat(data))
 
@@ -281,7 +289,10 @@ class DAGSpec(MutableMapping):
                     Path(self.data['meta']['import_tasks_from']).read_text())
 
                 if self.env is not None:
-                    imported = expand_raw_dictionaries(imported, self.env)
+                    (imported,
+                     tags_other) = expand_raw_dictionaries_and_extract_tags(
+                         imported, self.env)
+                    tags = tags | tags_other
 
                 # relative paths here are relative to the file where they
                 # are declared
@@ -293,6 +304,15 @@ class DAGSpec(MutableMapping):
 
                 self.data['tasks'].extend(imported)
 
+            # check if there are any params declared in env, not used in
+            # in the pipeline
+            extra = set(self.env) - self.env.default_keys - tags
+
+            if extra:
+                warnings.warn('The following placeholders are declared in the '
+                              'environment but '
+                              f'unused in the spec: {extra}')
+
             self.data['tasks'] = [
                 normalize_task(task) for task in self.data['tasks']
             ]
@@ -412,13 +432,18 @@ class DAGSpec(MutableMapping):
 
         return dag
 
+    @property
+    def path(self):
+        return self._path
+
     @classmethod
     def _auto_load(cls,
                    to_dag=True,
                    starting_dir=None,
                    env=None,
                    lazy_import=False,
-                   reload=False):
+                   reload=False,
+                   name=None):
         """
         NOTE: this is a private API. Use DAGSpec.find() instead
 
@@ -436,7 +461,7 @@ class DAGSpec(MutableMapping):
         Returns DAG and the directory where the pipeline.yaml file is located.
         """
         root_path = starting_dir or os.getcwd()
-        rel_path = entry_point(root_path=root_path)
+        rel_path = entry_point(root_path=root_path, name=name)
 
         if rel_path is None:
             if to_dag:
@@ -456,15 +481,32 @@ class DAGSpec(MutableMapping):
 
         except Exception as e:
             exc = DAGSpecInitializationError('Error initializing DAG from '
-                                             'pipeline.yaml')
+                                             f'{path!s}')
             raise exc from e
 
+    @classmethod
+    def _find_relative(cls, name=None):
+        """
+        Searches for a spec in default locations relative to the current
+        working directory
+
+        Notes
+        -----
+        This is a private API used by Soopervisor to locate which YAML spec
+        to use for exporting. It needs a relative path since the location
+        is used for loading the DAG and submitting tasks and as an argument
+        in "ploomber task --entry-point {relative-path}" when executing tasks
+        """
+        path = entry_point_relative(name=name)
+        return cls(path)
+
     @classmethod
     def find(cls,
              env=None,
              reload=False,
              lazy_import=False,
-             starting_dir=None):
+             starting_dir=None,
+             name=None):
         """
         Automatically find pipeline.yaml and return a DAGSpec object, which
         can be converted to a DAG using .to_dag()
@@ -473,12 +515,17 @@ class DAGSpec(MutableMapping):
         ----------
         env
             The environment to pass to the spec
+
+        name : str, default=None
+            Filename to search for. If None, it looks for a pipeline.yaml file,
+            otherwise it looks for a pipeline.{name}.yaml file.
         """
         spec, _ = DAGSpec._auto_load(to_dag=False,
                                      starting_dir=starting_dir,
                                      env=env,
                                      lazy_import=lazy_import,
-                                     reload=reload)
+                                     reload=reload,
+                                     name=name)
         return spec
 
     @classmethod
