@@ -60,6 +60,7 @@ from ploomber.tasks.taskgroup import TaskGroup
 from ploomber.constants import TaskStatus
 from ploomber.tasks._upstream import Upstream
 from ploomber.tasks._params import Params
+from ploomber.tasks.util import download_products_in_parallel
 from ploomber.Table import TaskReport, Row
 from ploomber.util import isiterable
 from ploomber.util.util import callback_check
@@ -136,7 +137,7 @@ class Task(abc.ABC):
             if self._name is None:
                 raise AttributeError('Task name can only be None if it '
                                      'can be inferred from the source object. '
-                                     'This only works when the task receives a'
+                                     'For example, when the task receives a '
                                      'pathlib.Path, when using SourceLoader '
                                      'or in PythonCallable. Pass a value '
                                      'explicitly')
@@ -340,7 +341,9 @@ class Task(abc.ABC):
             # and ensure the task uses the downloaded metadata
             self.product.metadata.clear()
         else:
-            self.product.metadata.update(str(self.source))
+            self.product.metadata.update(
+                source_code=str(self.source),
+                params=self.params.to_json_serializable(params_only=True))
 
         # For most Products, it's ok to do this check before
         # saving metadata, but not for GenericProduct, since the way
@@ -465,6 +468,10 @@ class Task(abc.ABC):
         DAGBuildEarlyStop
             If any task or on_finish hook raises a DAGBuildEarlyStop error
         """
+        # This is the public API for users who'd to run tasks in isolation,
+        # we have to make sure we clear product cache status, otherwise
+        # this will interfere with other render calls
+        self.render(force=force)
 
         upstream_exec_status = [t.exec_status for t in self.upstream.values()]
 
@@ -495,14 +502,8 @@ class Task(abc.ABC):
                     'up-to-date copies to remote storage and they will be '
                     'automatically downloaded')
 
-            for t in ok:
-                if t.exec_status == TaskStatus.WaitingDownload:
-                    t.product.download()
-
-        # This is the public API for users who'd to run tasks in isolation,
-        # we have to make sure we clear product cache status, otherwise
-        # this will interfere with other render calls
-        self.render(force=force)
+            download_products_in_parallel(
+                t for t in ok if t.exec_status == TaskStatus.WaitingDownload)
 
         # at this point the task must be WaitingDownload or WaitingExecution
         res, _ = self._build(catch_exceptions=catch_exceptions)
@@ -605,8 +606,8 @@ class Task(abc.ABC):
 
     def _run(self):
         """
-        Run task if certain status conditions are ok, otherwise raise a
-        TaskBuildError exception
+        Run or download task if certain status conditions are met, otherwise
+        raise a TaskBuildError exception
         """
         # cannot keep running, we depend on the render step to get all the
         # parameters resolved (params, upstream, product)
@@ -659,7 +660,7 @@ class Task(abc.ABC):
 
         return TaskReport.with_data(name=self.name, ran=True, elapsed=elapsed)
 
-    def render(self, force=False, outdated_by_code=True):
+    def render(self, force=False, outdated_by_code=True, remote=False):
         """
         Renders code and product, all upstream tasks must have been rendered
         first, for that reason, this method will usually not be called
@@ -679,6 +680,9 @@ class Task(abc.ABC):
             Factors to determine if Task.product is marked outdated when source
             code changes. Otherwise just the upstream timestamps are used.
 
+        remote : bool, default=False
+            Use remote metadata to determine status
+
         Notes
         -----
         This method tries to avoid calls to check for product status whenever
@@ -714,7 +718,9 @@ class Task(abc.ABC):
         # we use outdated status several time, this caches the result
         # for performance reasons. TODO: move this to Product and make it
         # a property
-        is_outdated = ProductEvaluator(self.product, outdated_by_code)
+        is_outdated = ProductEvaluator(self.product,
+                                       outdated_by_code,
+                                       remote=remote)
 
         # task with no dependencies
         if not self.upstream:
@@ -748,29 +754,19 @@ class Task(abc.ABC):
 
             # some upstream tasks need execution (or download)
             if not all_upstream_ready:
-                # special case: if all upstream tasks can be downloaded and
-                # this one too, we can do so
-                # FIXME:  I dont think i need this, should be taken care
-                # by is_outdated.check()
-                if upstream_exec_status <= {
-                        TaskStatus.WaitingDownload, TaskStatus.Skipped
-                } and is_outdated.check() == TaskStatus.WaitingDownload:
-                    self._exec_status = TaskStatus.WaitingDownload
-                elif force or is_outdated.check():
+                if force or is_outdated.check() is True:
                     self._exec_status = TaskStatus.WaitingUpstream
+                elif is_outdated.check() == TaskStatus.WaitingDownload:
+                    self._exec_status = TaskStatus.WaitingDownload
                 else:
                     self._exec_status = TaskStatus.Skipped
 
-            # al upstream ready
+            # all upstream ready
             else:
-                # check if we need to execute or download
-                if force or is_outdated.check():
-                    # This only happens with File
-                    if is_outdated.check() == TaskStatus.WaitingDownload:
-                        self._exec_status = TaskStatus.WaitingDownload
-                    else:
-                        self._exec_status = TaskStatus.WaitingExecution
-                # task is up-to-date, nothing to do
+                if force or is_outdated.check() is True:
+                    self._exec_status = TaskStatus.WaitingExecution
+                elif is_outdated.check() == TaskStatus.WaitingDownload:
+                    self._exec_status = TaskStatus.WaitingDownload
                 else:
                     self._exec_status = TaskStatus.Skipped
 
@@ -1004,14 +1000,18 @@ class ProductEvaluator:
     A class to temporarily keep the outdated status of a product (when products
     are remote this operation is expensive)
     """
-    def __init__(self, product, outdated_by_code):
+    def __init__(self, product, outdated_by_code, remote):
         self.product = product
         self.outdated_by_code = outdated_by_code
         self._is_outdated = None
+        self._remote = remote
 
     def check(self):
         if self._is_outdated is None:
-            self._is_outdated = (self.product._is_outdated(
+            callable_ = (self.product._is_remote_outdated
+                         if self._remote else self.product._is_outdated)
+
+            self._is_outdated = (callable_(
                 outdated_by_code=self.outdated_by_code))
 
         return self._is_outdated
