@@ -27,9 +27,10 @@ from ploomber.products import MetaProduct, File
 
 def _unserializer(product, unserializer):
     # this happens when we have a task group
-    if isinstance(product, Mapping):
+    if isinstance(product, Mapping) and not isinstance(product, MetaProduct):
         return {k: unserializer(p) for k, p in product.items()}
     else:
+        # pass metaproduct and products directly to the unserializer function
         return unserializer(product)
 
 
@@ -454,7 +455,7 @@ class Input(Task):
     def _init_source(kwargs):
         return EmptySource(None, **kwargs)
 
-    def _null_update_metadata(self, metadata):
+    def _null_update_metadata(self, source_code, params):
         # this should be __null_update_metadata but we can't due to
         # https://bugs.python.org/issue33007
         pass
