@@ -12,7 +12,7 @@ from contextlib import contextmanager
 from ploomber.exceptions import CallbackSignatureError, TaskRenderError
 
 
-def requires(pkgs, name=None, extra_msg=None):
+def requires(pkgs, name=None, extra_msg=None, pip_names=None):
     """
     Check if packages were imported, raise ImportError with an appropriate
     message for missing ones
@@ -31,22 +31,35 @@ def requires(pkgs, name=None, extra_msg=None):
 
     extra_msg
         Append this extra message to the end
+
+    pip_names
+        Pip package names to show in the suggested "pip install {name}"
+        command, use it if different to the package name itself
+
     """
     def decorator(f):
         @wraps(f)
         def wrapper(*args, **kwargs):
-            missing = [
-                pkg for pkg in pkgs if importlib.util.find_spec(pkg) is None
+            is_pkg_missing = [
+                importlib.util.find_spec(pkg) is None for pkg in pkgs
             ]
 
-            if missing:
-                msg = reduce(lambda x, y: x + ' ' + y, missing)
+            if any(is_pkg_missing):
+                missing_pkgs = [
+                    name for name, is_missing in zip(
+                        pip_names or pkgs, is_pkg_missing) if is_missing
+                ]
+                names_str = reduce(lambda x, y: x + ' ' + y, missing_pkgs)
+
                 fn_name = name or f.__name__
                 error_msg = ('{} {} required to use {}. Install {} by '
                              'running "pip install {}"'.format(
-                                 msg, 'is' if len(missing) == 1 else 'are',
+                                 names_str,
+                                 'is' if len(missing_pkgs) == 1 else 'are',
                                  fn_name,
-                                 'it' if len(missing) == 1 else 'them', msg))
+                                 'it' if len(missing_pkgs) == 1 else 'them',
+                                 names_str,
+                             ))
 
                 if extra_msg:
                     error_msg += ('. ' + extra_msg)
@@ -84,6 +97,10 @@ def isiterable(obj):
         return True
 
 
+def isiterable_not_str(obj):
+    return isinstance(obj, Iterable) and not isinstance(obj, str)
+
+
 # TODO: add more context to errors, which task and which hook?
 def callback_check(fn, available, allow_default=True):
     """
@@ -158,14 +175,22 @@ def signature_check(fn, params, task_name):
     errors = []
 
     if extra:
-        msg = ('The following params are not part of the function '
-               'signature: {}'.format(extra))
+        msg = f'Got unexpected arguments: {sorted(extra)}'
         errors.append(msg)
 
     if missing:
-        msg = 'The following params are missing: {}'.format(missing)
+        msg = f'Missing arguments: {sorted(missing)}'
         errors.append(msg)
 
+    if 'upstream' in missing:
+        errors.append('Verify this task declared upstream depedencies or '
+                      'remove the "upstream" argument from the function')
+
+    missing_except_upstream = sorted(missing - {'upstream'})
+
+    if missing_except_upstream:
+        errors.append(f'Pass {missing_except_upstream} in "params"')
+
     if extra or missing:
         msg = '. '.join(errors)
         # not all functions have __name__ (e.g. partials)
@@ -191,95 +216,6 @@ def _parse_module(dotted_path, raise_=True):
     return '.'.join(parts[:-1]), parts[-1]
 
 
-def load_dotted_path(dotted_path, raise_=True):
-    """Load an object/function/module by passing a dotted path
-
-    Parameters
-    ----------
-    dotted_path : str
-        Dotted path to a module, e.g. ploomber.tasks.NotebookRunner
-    raise_ : bool, optional
-        If True, an exception is raised if the module can't be imported,
-        otherwise return None if that happens
-    """
-    obj, module = None, None
-
-    parsed = _parse_module(dotted_path, raise_=raise_)
-
-    if parsed:
-        mod, name = parsed
-
-        try:
-            module = importlib.import_module(mod)
-        except ImportError as e:
-            if raise_:
-                # we want to raise ethe same error type but chaining exceptions
-                # produces a long verbose output, so we just modify the
-                # original message to add more context, it's ok to hide the
-                # original traceback since it will just point to lines
-                # in the importlib module, which isn't useful for the user
-                e.msg = ('An error happened when trying to '
-                         'import dotted path "{}": {}'.format(
-                             dotted_path, str(e)))
-                raise
-
-        if module:
-            try:
-                obj = getattr(module, name)
-            except AttributeError as e:
-                if raise_:
-                    # same as in the comment above
-                    e.args = (
-                        'Could not get "{}" from module '
-                        '"{}" (loaded from: {}), make sure it is a valid '
-                        'callable defined in such module'.format(
-                            name, mod, module.__file__), )
-                    raise
-        return obj
-    else:
-        if raise_:
-            raise ValueError(
-                'Invalid dotted path value "{}", must be a dot separated '
-                'string, with at least '
-                '[module_name].[function_name]'.format(dotted_path))
-
-
-def locate_dotted_path(dotted_path):
-    """
-    Locates a dotted path, returns the spec for the module where the attribute
-    is defined
-    """
-    tokens = dotted_path.split('.')
-    module = '.'.join(tokens[:-1])
-    spec = importlib.util.find_spec(module)
-
-    if spec is None:
-        raise ModuleNotFoundError(f'Module {module!r} does not exist')
-
-    return spec
-
-
-def find_file_recursively(name, max_levels_up=6, starting_dir=None):
-    """
-    Find environment by looking into the current folder and parent folders,
-    returns None if no file was found otherwise pathlib.Path to the file
-    """
-    current_dir = starting_dir or os.getcwd()
-    current_dir = Path(current_dir)
-    path_to_file = None
-
-    for _ in range(max_levels_up):
-        current_path = Path(current_dir, name)
-
-        if current_path.exists():
-            path_to_file = current_path.resolve()
-            break
-
-        current_dir = current_dir.parent
-
-    return path_to_file
-
-
 def call_with_dictionary(fn, kwargs):
     """
     Call a function by passing elements from a dictionary that appear in the
